embassy-net-adin1110

Crates

git

Versions

default

Flavors

ADIN1110

Struct ADIN1110 

pub struct ADIN1110<P: Adin1110Protocol> { /* private fields */ }
ADIN1110 embassy-net driver

Implementations

Source

impl<P: Adin1110Protocol> ADIN1110<P>

pub fn new(protocol: P) -> Self

Create a new ADIN1110 instance.

pub async fn read_reg(&mut self, reg: sr) -> AEResult<u32, P::SpiError>

Read a SPI register

pub async fn write_reg( &mut self, reg: sr, value: u32, ) -> AEResult<(), P::SpiError>

Write a SPI register

pub async fn read_fifo( &mut self, frame: &mut [u8], ) -> AEResult<usize, P::SpiError>

Read out fifo ethernet packet memory received via the wire.

pub async fn write_fifo(&mut self, frame: &[u8]) -> AEResult<(), P::SpiError>

Write to fifo ethernet packet memory send over the wire.

pub async fn set_mac_addr(&mut self, mac: &[u8; 6]) -> AEResult<(), P::SpiError>

Programs the mac address in the mac filters. Also set the boardcast address. The chip supports 2 priority queues but current code doesn’t support this mode.

Source

impl<SPI: SpiDevice> ADIN1110<GenericSpi<SPI>>

pub fn new_generic(spi: SPI, spi_crc: bool, append_fcs_on_tx: bool) -> Self

Create a driver instance using the Generic SPI protocol.